button - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- Button
- Switch

# Button

Button([value]) -> Button widget

A widget resembling a button.

### Arguments

value
  The text or widget to be displayed on the button.

# Switch

Switch([value, [on_label, [off_label]]]) -> Switch widget

This is very similar to a button except the value will always be ether True or False

### Arguments

value
  You can set it to True or False (default).
on_label
  The text displayed when the switch is on.
off_label
  The text displayed when the switch is off.